@@ -31,10 +31,12 @@ import matplotlib.image  as mplimg
 
 from   fsl.utils.platform import platform as fslplatform
 import fsl.utils.idle                     as idle
+import fsleyes_widgets                    as fwidgets
 import fsleyes_widgets.utils.status       as status
 import fsl.utils.settings                 as fslsettings
 import fsleyes.views.canvaspanel          as canvaspanel
 import fsleyes.views.plotpanel            as plotpanel
+import fsleyes.plotting.plotcanvas        as plotcanvas
 
 import fsleyes.strings as strings
 from . import             base
@@ -54,10 +56,12 @@ class ScreenshotAction(base.Action):
         :arg overlayList: The :class:`.OverlayList`.
         :arg displayCtx:  The :class:`.DisplayContext`.
         :arg panel:       The :class:`.CanvasPanel` or :class:`.PlotPanel` to
-                          take a screenshot of.
+                          take a screenshot of. :class:`.PlotCanvas` instances
+                          are also accepted.
         """
 
-        base.Action.__init__(self, self.__doScreenshot)
+        base.Action.__init__(
+            self, overlayList, displayCtx, self.__doScreenshot)
         self.__panel = panel
 
 
@@ -81,7 +85,7 @@ class ScreenshotAction(base.Action):
         # it is available
         if 'png' in fmts:
             fmts = [('png', fmts['png'])] + \
-                   [(k, v) for k, v in fmts.items() if k is not 'png']
+                   [(k, v) for k, v in fmts.items() if k != 'png']
         else:
             fmts = list(fmts.items())
 
@@ -90,7 +94,7 @@ class ScreenshotAction(base.Action):
         wildcard = '|'.join(wildcard)
         filename = 'screenshot'
 
-        dlg = wx.FileDialog(self.__panel,
+        dlg = wx.FileDialog(wx.GetTopLevelWindows()[0],
                             message=strings.messages[self, 'screenshot'],
                             wildcard=wildcard,
                             defaultDir=fromDir,
@@ -106,7 +110,7 @@ class ScreenshotAction(base.Action):
         # the screenshot gets taken
         dlg.Close()
         dlg.Destroy()
-        wx.Yield()
+        wx.GetApp().Yield()
 
         # Show an error if the screenshot
         # function raises an error
@@ -125,13 +129,14 @@ class ScreenshotAction(base.Action):
 
 
 def screenshot(panel, filename):
-    """Capture a screenshot of the contents of the given :class:`.CanvasPanel`
-    or :class:`.PlotPanel`, saving it to the given ``filename``.
+    """Capture a screenshot of the contents of the given :class:`.CanvasPanel`,
+    :class:`.PlotPanel`, or :class:`.PlotCanvas`, saving it to the given
+    ``filename``.
     """
 
     if isinstance(panel, canvaspanel.CanvasPanel):
         canvasPanelScreenshot(panel, filename)
-    elif isinstance(panel, plotpanel.PlotPanel):
+    elif isinstance(panel, (plotpanel.PlotPanel, plotcanvas.PlotCanvas)):
         plotPanelScreenshot(panel, filename)
 
 
@@ -139,7 +144,14 @@ def plotPanelScreenshot(panel, filename):
     """Capture a screenshot of the contents of the given :class:`.PlotPanel`
     or :class:`.PlotPanel`, saving it to the given ``filename``.
     """
-    panel.getFigure().savefig(filename)
+    if isinstance(panel, plotpanel.PlotPanel):
+        figure = panel.canvas.figure
+    elif isinstance(panel, plotcanvas.PlotCanvas):
+        figure = panel.figure
+    else:
+        raise ValueError('Unsupported panel type: {}'.format(type(panel)))
+
+    figure.savefig(filename)
 
 
 def canvasPanelScreenshot(panel, filename):
@@ -180,7 +192,7 @@ def canvasPanelScreenshot(panel, filename):
     windowDC = wx.WindowDC(panel)
     memoryDC = wx.MemoryDC()
 
-    if fslplatform.wxFlavour == fslplatform.WX_PHOENIX:
+    if fwidgets.wxFlavour() == fwidgets.WX_PHOENIX:
         bmp = wx.Bitmap(width, height)
     else:
         bmp = wx.EmptyBitmap(width, height)
@@ -204,7 +216,7 @@ def canvasPanelScreenshot(panel, filename):
     data[:, :, :3] = rgb.reshape(height, width, 3)
 
     # OSX and SSh/X11 both have complications
-    inSSH = fslplatform.inSSHSession and not fslplatform.inVNCSession
+    inSSH = fwidgets.inSSHSession() and not fwidgets.inVNCSession()
     if inSSH or fslplatform.os == 'Darwin':
         data = _patchInCanvases(cpanel, panel, data, bgColour)
 
