@@ -14,15 +14,16 @@ import numpy as np
 
 import wx
 
-import fsleyes_props            as props
-import fsleyes_widgets.elistbox as elistbox
+import fsleyes_props                 as props
+import fsleyes_widgets.elistbox      as elistbox
 
-import fsleyes.panel            as fslpanel
-import fsleyes.tooltips         as fsltooltips
-import fsleyes.strings          as strings
+import fsleyes.controls.controlpanel as ctrlpanel
+import fsleyes.views.plotpanel       as plotpanel
+import fsleyes.tooltips              as fsltooltips
+import fsleyes.strings               as strings
 
 
-class PlotListPanel(fslpanel.FSLeyesPanel):
+class PlotListPanel(ctrlpanel.ControlPanel):
     """The ``PlotListPanel`` is a *FSLeyes control* panel for use with
     :class:`.OverlayPlotPanel` views. It allows the user to add and remove
     :class:`.DataSeries` instances from the :attr:`.PlotPanel.dataSeries`
@@ -39,7 +40,24 @@ class PlotListPanel(fslpanel.FSLeyesPanel):
     """
 
 
-    def __init__(self, parent, overlayList, displayCtx, frame, plotPanel):
+    @staticmethod
+    def supportedViews():
+        """The ``PlotListPanel`` is restricted for use with
+        :class:`.OverlayPlotPanel` views. This method may be overridden by
+        sub-classes.
+        """
+        return [plotpanel.OverlayPlotPanel]
+
+
+    @staticmethod
+    def defaultLayout():
+        """Returns a dictionary containing layout settings to be passed to
+        :class:`.ViewPanel.togglePanel`.
+        """
+        return {'location' : wx.LEFT}
+
+
+    def __init__(self, parent, overlayList, displayCtx, plotPanel):
         """Create a ``PlotListPanel``.
 
         :arg parent:      The :mod:`wx` parent object.
@@ -48,14 +66,12 @@ class PlotListPanel(fslpanel.FSLeyesPanel):
 
         :arg displayCtx:  The :class:`.DisplayContext` instance.
 
-        :arg frame:       The :class:`.FSLeyesFrame` instance.
-
         :arg plotPanel:   The :class:`.OverlayPlotPanel` associated with this
                           ``PlotListPanel``.
         """
 
-        fslpanel.FSLeyesPanel.__init__(
-            self, parent, overlayList, displayCtx, frame)
+        ctrlpanel.ControlPanel.__init__(
+            self, parent, overlayList, displayCtx, plotPanel)
 
         self.__plotPanel = plotPanel
         self.__dsList    = elistbox.EditableListBox(
@@ -73,9 +89,9 @@ class PlotListPanel(fslpanel.FSLeyesPanel):
         self.__dsList.Bind(elistbox.EVT_ELB_EDIT_EVENT,   self.__onListEdit)
         self.__dsList.Bind(elistbox.EVT_ELB_SELECT_EVENT, self.__onListSelect)
 
-        self.__plotPanel.addListener('dataSeries',
-                                     self.name,
-                                     self.__dataSeriesChanged)
+        self.__plotPanel.canvas.addListener('dataSeries',
+                                            self.name,
+                                            self.__dataSeriesChanged)
 
         self.__dataSeriesChanged()
         self.Layout()
@@ -85,13 +101,17 @@ class PlotListPanel(fslpanel.FSLeyesPanel):
     def destroy(self):
         """Must be called when this ``PlotListPanel`` is no longer
         needed. Removes some property listeners, and calls the
-        :meth:`.FSLeyesPanel.destroy` method.
+        :meth:`.ControlPanel.destroy` method.
         """
 
-        self.__plotPanel.removeListener('dataSeries', self.name)
+        # the plot panel may have already
+        # cleared its canvas ref before we
+        # get destroyed
+        if self.__plotPanel.canvas is not None:
+            self.__plotPanel.canvas.removeListener('dataSeries', self.name)
         self.__plotPanel = None
         self.__dsList.Clear()
-        fslpanel.FSLeyesPanel.destroy(self)
+        ctrlpanel.ControlPanel.destroy(self)
 
 
     def __dataSeriesChanged(self, *a):
@@ -102,7 +122,7 @@ class PlotListPanel(fslpanel.FSLeyesPanel):
 
         self.__dsList.Clear()
 
-        for ds in self.__plotPanel.dataSeries:
+        for ds in self.__plotPanel.canvas.dataSeries:
             widg = DataSeriesWidget(self, ds)
             self.__dsList.Append(
                 ds.label,
@@ -162,7 +182,7 @@ class PlotListPanel(fslpanel.FSLeyesPanel):
         :class:`.DataSeries` instance from the :attr:`.PlotPanel.dataSeries`
         list of the :class:`.OverlayPlotPanel`.
         """
-        with props.skip(self.__plotPanel, 'dataSeries', self.name):
+        with props.skip(self.__plotPanel.canvas, 'dataSeries', self.name):
             self.__plotPanel.dataSeries.remove(ev.data)
 
 
