@@ -44,6 +44,13 @@ Quick start
     # call our function when it is ready.
     fslgl.getGLContext(ready=ready)
 
+    # ...
+
+    # When you're finished, call the shutdown
+    # function to clear the context (only
+    # necessary for on-screen rendering)
+    fslgl.shutdown()
+
 
 --------
 Canvases
@@ -178,10 +185,12 @@ been created.
 
 
 import os
+import sys
 import logging
 import platform
 
 import fsl.utils.idle                     as idle
+import fsl.version                        as fslversion
 from   fsl.utils.platform import platform as fslplatform
 import fsleyes_widgets                    as fwidgets
 
@@ -189,13 +198,6 @@ import fsleyes_widgets                    as fwidgets
 log = logging.getLogger(__name__)
 
 
-# When running under X, indirect rendering fails for
-# unknown reasons, so I'm forcing direct rendering.
-# If direct rendering is not available, I don't know
-# what to do.
-os.environ.pop('LIBGL_ALWAYS_INDIRECT', None)
-
-
 import OpenGL  # noqa
 
 
@@ -215,11 +217,76 @@ OpenGL.ERROR_LOGGING  = True
 # OpenGL.FULL_LOGGING   = True
 
 
-# Using PyOpenGL 3.1 (and OSX Mavericks 10.9.4 on a MacbookPro11,3), the
-# OpenGL.contextdata.setValue method throws 'unhashable type' TypeErrors
-# unless we set STORE_POINTERS to False. I don't know why.
-if os.environ.get('PYOPENGL_PLATFORM', None) == 'osmesa':
-    OpenGL.STORE_POINTERS = False
+GL_VERSION = None
+"""Set in :func:`bootstrap`. String containing the available "major.minor"
+OpenGL version.
+"""
+
+
+GL_COMPATIBILITY = None
+"""Set in :func:`bootstrap`. String containing the target "major.minor"
+OpenGL compatibility version ("1.4" or "2.1").
+"""
+
+
+GL_RENDERER = None
+"""Set in :func:`bootstrap`. Contains a description of the OpenGL renderer in
+ use.
+"""
+
+
+def _selectPyOpenGLPlatform():
+    """Pyopengl sometimes doesn't select a suitable platform, so in some
+    circumstances we need to force things (but not if ``PYOPENGL_PLATFORM``
+    is already set in the environment).
+    """
+    if 'PYOPENGL_PLATFORM' in os.environ:
+        return
+
+    # If no display, osmesa on all platforms
+    if not fwidgets.canHaveGui():
+        os.environ['PYOPENGL_PLATFORM'] = 'osmesa'
+
+    # GTK3 versions of wxpython 4.1.1 and newer
+    # default to using EGL for GL initialisation,
+    # but pyopengl defaults to glx.
+    elif fslplatform.os.lower() == 'linux':
+        wxver  = fwidgets.wxVersion()
+        wxplat = fwidgets.wxPlatform()
+
+        if wxver is not None                               and \
+           fslversion.compareVersions(wxver, '4.1.1') >= 0 and \
+           wxplat == fwidgets.WX_GTK3:
+            os.environ['PYOPENGL_PLATFORM'] = 'egl'
+
+
+_selectPyOpenGLPlatform()
+
+
+def glIsSoftwareRenderer():
+    """Returns ``True`` if the OpenGL renderer appears to be software based,
+    ``False`` otherwise, or ``None`` :func:`bootstrap` has not been called yet.
+
+    .. note:: This check is based on heuristics, ans is not guaranteed to
+              be correct.
+    """
+    if GL_RENDERER is None:
+        return None
+
+    # There doesn't seem to be any quantitative
+    # method for determining whether we are using
+    # software-based rendering, so a hack is
+    # necessary.
+    renderer = GL_RENDERER.lower()
+
+    # "software" / "chromium" -> software renderer
+    # But SVGA3D/llvmpipe are super fast, so if
+    # we're using either of them, pretend that
+    # we're on hardware
+    sw     = any(('software' in renderer, 'chromium' in renderer))
+    fastsw = any(('llvmpipe' in renderer, 'svga3d'   in renderer))
+
+    return sw and (not fastsw)
 
 
 def bootstrap(glVersion=None):
@@ -244,9 +311,11 @@ def bootstrap(glVersion=None):
 
 
     ====================== ====================================================
-    ``GL_VERSION``         A string containing the target OpenGL version, in
+    ``GL_COMPATIBILITY``   A string containing the target OpenGL version, in
                            the format ``major.minor``, e.g. ``2.1``.
 
+    ``GL_VERSION``         A string containing the available OpenGL version.
+
     ``GL_RENDERER``        A string containing the name of the OpenGL renderer.
 
     ``glvolume_funcs``     The version-specific module containing functions for
@@ -281,17 +350,11 @@ def bootstrap(glVersion=None):
     ====================== ====================================================
 
 
-    This function also sets the :attr:`.Platform.glVersion` and
-    :attr:`.Platform.glRenderer` properties of the
-    :attr:`fsl.utils.platform.platform` instance.
-
-
     :arg glVersion: A tuple containing the desired (major, minor) OpenGL API
                     version to use. If ``None``, the best possible API
                     version will be used.
     """
 
-    import sys
     import OpenGL.GL         as gl
     import OpenGL.extensions as glexts
     from . import               gl14
@@ -303,8 +366,8 @@ def bootstrap(glVersion=None):
         return
 
     if glVersion is None:
-        glVer = gl.glGetString(gl.GL_VERSION).decode('latin1').split()[0]
-        major, minor = [int(v) for v in glVer.split('.')][:2]
+        glver = gl.glGetString(gl.GL_VERSION).decode('latin1').split()[0]
+        major, minor = [int(v) for v in glver.split('.')][:2]
     else:
         major, minor = glVersion
 
@@ -338,7 +401,7 @@ def bootstrap(glVersion=None):
                         'to an older OpenGL implementation.'
                         .format(', '.join(exts)))
             verstr = '1.4'
-            glpkg = gl14
+            glpkg  = gl14
 
     # If using GL14, and the ARB_vertex_program
     # and ARB_fragment_program extensions are
@@ -370,30 +433,8 @@ def bootstrap(glVersion=None):
     log.debug('Using OpenGL {} implementation with renderer {}'.format(
         verstr, renderer))
 
-    # If using freeglut, we need to call
-    # glutInit. If not (e.g. on mac, which
-    # provides its own GLUT implementation),
-    # we don't need to bother.
-    #
-    # note: GLUT is only required for text
-    #       rendering. The GLUT requirement
-    #       means that true off-screen (i.e.
-    #       headless) rendering is not
-    #       currently possible, although
-    #       would be if we removed GLUT
-    #       as a requirement. Off-screen
-    #       rendering is possible via other
-    #       means (e.g. xvfb-run).
-
-    import OpenGL.GLUT as GLUT
-    # it would be nice if there were a
-    # nicer way to test for freeglut
-    if bool(GLUT.fgDeinitialize):
-        GLUT.glutInit()
-
-    # Populate this module, and set
-    # the fsl.utils.platform GL fields
-    thismod.GL_VERSION         = verstr
+    thismod.GL_VERSION         = str(glVersion)
+    thismod.GL_COMPATIBILITY   = verstr
     thismod.GL_RENDERER        = renderer
     thismod.glvolume_funcs     = glpkg.glvolume_funcs
     thismod.glrgbvolume_funcs  = glpkg.glrgbvolume_funcs
@@ -406,18 +447,10 @@ def bootstrap(glVersion=None):
     thismod.glsh_funcs         = glpkg.glsh_funcs
     thismod.glmip_funcs        = glpkg.glmip_funcs
     thismod._bootstrapped      = True
-    fslplatform.glVersion      = glVersion
-    fslplatform.glRenderer     = thismod.GL_RENDERER
 
     # If we're using a software based renderer,
     # reduce the default performance settings
-    #
-    # But SVGA3D/llvmpipe are super fast, so if
-    # we're using either of them, pretend that
-    # we're on hardware
-    if fslplatform.glIsSoftwareRenderer                 and \
-       'llvmpipe' not in fslplatform.glRenderer.lower() and \
-       'svga3d'   not in fslplatform.glRenderer.lower():
+    if glIsSoftwareRenderer():
 
         log.debug('Software-based rendering detected - '
                   'lowering default performance settings.')
@@ -440,8 +473,6 @@ def getGLContext(**kwargs):
                  until it has been called!
     """
 
-    import sys
-
     thismod = sys.modules[__name__]
 
     # A context has already been created
@@ -460,13 +491,31 @@ def getGLContext(**kwargs):
     return thismod._glContext
 
 
-class GLContext(object):
+def shutdown():
+    """Must be called when the GL rendering context is no longer needed.
+    Destroys the context object, and resources associated with it.
+
+    Does not need to be called for off-screen rendering.
+    """
+
+    thismod = sys.modules[__name__]
+    context = getattr(thismod, '_glContext', None)
+    if context is not None:
+        context.destroy()
+        delattr(thismod, '_glContext')
+
+
+class GLContext:
     """The ``GLContext`` class manages the creation of, and access to, an
     OpenGL context. This class abstracts away the differences between
     creation of on-screen and off-screen rendering contexts.
-    It contains a single method, :meth:`setTarget`, which may
-    be used to set a :class:`.WXGLCanvasTarget` or an
-    :class:`OffScreenCanvasTarget` as the GL rendering target.
+    It contains two methods:
+
+      - :meth:`setTarget`, which may be used to set a
+        :class:`.WXGLCanvasTarget` or an :class:`OffScreenCanvasTarget` as the
+        GL rendering target.
+      - :meth:`destroy`, which must be called when the context is no longer
+        needed.
 
 
     On-screen rendering is performed via the ``wx.GLCanvas.GLContext``
@@ -489,6 +538,12 @@ class GLContext(object):
     ``GLCanvas``, and displays it, before creating the ``wx`` GL context.
 
 
+    A reference to this dummy ``wx.Frame`` is retained, because destroying it
+    can result in ``GLXBadCurrentWindow`` errors when running on
+    macOS+XQuartz. The frame is destroyed on calls to the ``GLContext.destroy``
+    method.
+
+
     Because ``wx`` contexts may be used even when an off-screen rendering
     context has been requested, the ``GLContext`` class has the ability to
     create and run a temporary ``wx.App``, on which the canvas and context
@@ -555,10 +610,12 @@ class GLContext(object):
         self.__context   = None
         self.__canvas    = None
         self.__parent    = None
+        self.__buffer    = None
         self.__app       = None
 
-        canHaveGui       = fslplatform.canHaveGui
-        haveGui          = fslplatform.haveGui
+        osmesa     = os.environ.get('PYOPENGL_PLATFORM', None) == 'osmesa'
+        canHaveGui = fwidgets.canHaveGui()
+        haveGui    = fwidgets.haveGui()
 
         # On-screen contexts *must* be
         # created via a wx event loop
@@ -567,9 +624,10 @@ class GLContext(object):
                              'created on the wx.MainLoop')
 
         # For off-screen, only use OSMesa
-        # if we have no cnoice. Otherewise
-        # we use wx if possible
-        if offscreen and not canHaveGui:
+        # if we have no cnoice, or if
+        # dictated by PYOPENGL_PLATFORM.
+        # Otherewise we use wx if possible.
+        if offscreen and (osmesa or (not canHaveGui)):
             self.__createOSMesaContext()
             ready()
             return
@@ -627,30 +685,12 @@ class GLContext(object):
                     if raiseErrors:
                         raise e
 
-            # Once the GL context has been
-            # created, we no longer need
-            # references to the wx objects
-            #
-            # (note: when running with macOS
-            # and XQuartz over SSH/X11, a
-            # GLXBadCurrentWindow can occur if
-            # we close/destroy the parent/canvas
-            # too soon after creating a GL
-            # context. Things seem to work ok if
-            # we do it after the ready() callback
-            # has been called (in normal
-            # circumstances, this creates the
-            # FSLeyesFrame, OverlayList, and
-            # DisplayContext - see fsleyes.main.main).
-
-            # I'm not sure if this is a timing
-            # issue, or if the ready() callback
-            # is doing something which causes the
-            # error to not occur.
-            self.__parent.Close()
-            self.__parent = None
-            self.__canvas = None
-            self.__app    = None
+            # We keep the parent around, because
+            # destroying it can cause GLXBadCurrentWindow
+            # errors when running on macOS+XQuartz. It is
+            # destroyed when the GLContext.destroy() method
+            # is called.
+            self.__parent.Hide()
 
         # If we've created our own wx.App, run its
         # main loop - we need to run the loop
@@ -667,13 +707,55 @@ class GLContext(object):
             self.__app.MainLoop()
 
 
-    def setTarget(self, target):
+    def destroy(self):
+        """Called by the module-level :func:`shutdown` function. If this is an
+        on-screen context, the dummy canvas and frame that were created at
+        initialisation are destroyed.
+        """
+
+        # We need to destroy the OSMesa context,
+        # otherwise it will stay in memory
+        if self.__buffer is not None:
+            import OpenGL.raw.osmesa.mesa as osmesa
+            osmesa.OSMesaDestroyContext(self.__context)
+
+        # Clear refs to wx frame/canvas
+        # before destroying the wx.App,
+        # as problems can otherwise occur
+        app            = self.__app
+        self.__app     = None
+        self.__context = None
+        self.__buffer  = None
+        self.__parent  = None
+        self.__canvas  = None
+
+        if app is not None:
+            app.Destroy()
+
+
+    def setTarget(self, target=None):
         """Set the given ``WXGLCanvasTarget`` or ``OffScreenCanvasTarget`` as
         the target for GL rendering with this context.
+
+        If ``target`` is None, and this is an on-screen rendering context,
+        the dummy ``wx.glcanvas.GLCanvas`` that was used to create this
+        ``GLContext`` is set as the rendering target.
         """
-        import wx.glcanvas as wxgl
-        if not self.__offscreen and isinstance(target, wxgl.GLCanvas):
-            self.__context.SetCurrent(target)
+        # not necessary for offscreen rendering
+        if self.__offscreen:
+            return True
+
+        # destroy() has been called
+        if self.__context is None:
+            return False
+
+        if target is None and self.__canvas is not None:
+            return self.__context.SetCurrent(self.__canvas)
+
+        else:
+            import wx.glcanvas as wxgl
+            if isinstance(target, wxgl.GLCanvas):
+                return self.__context.SetCurrent(target)
 
 
     def __createWXGLParent(self):
@@ -681,10 +763,20 @@ class GLContext(object):
         dummy ``wx.glcanvas.GLCanvas``.
         """
 
-        log.debug('Creating temporary wx.Frame')
-
         import wx
-        self.__parent = wx.Frame(None, style=0)
+
+        # Override ShouldPreventAppExit, meaning
+        # that the wx.App.MainLoop will exit even
+        # if a DummyFrame still exists. The wx
+        # equivalent of marking a thread as a
+        # daemon.
+        class DummyFrame(wx.Frame):
+            def ShouldPreventAppExit(self):
+                return False
+
+        log.debug('Creating dummy wx.Frame for GL context creation')
+
+        self.__parent = DummyFrame(None, style=0)
         self.__parent.SetSize((0, 0))
         self.__parent.Show(True)
 
@@ -708,18 +800,13 @@ class GLContext(object):
         # the first canvas, all canvases that are
         # subsequently created will inherit the
         # same properties.
-        attribs = [wxgl.WX_GL_RGBA,
-                   wxgl.WX_GL_DOUBLEBUFFER,
-                   wxgl.WX_GL_STENCIL_SIZE, 4,
-                   wxgl.WX_GL_DEPTH_SIZE,   24,
-                   0,
-                   0]
+        attrs = WXGLCanvasTarget.displayAttribues()
 
         # GLCanvas initialisation with an attribute
         # list fails when running in a nomachine-like
         # remote desktop session. No idea why.
         try:
-            self.__canvas = wxgl.GLCanvas(self.__parent, attribList=attribs)
+            self.__canvas = wxgl.GLCanvas(self.__parent, **attrs)
             self.__canvas.SetSize((0, 0))
 
         # Creating without attribute list works ok
@@ -751,13 +838,34 @@ class GLContext(object):
         import                wx
         import wx.glcanvas as wxgl
 
+        # Versions of wxwidgets 3.1 and newer (approximately
+        # corresponding to wxpython 4.1 and newer) allow
+        # us to select a GL compatibility profile (required,
+        # because we rely on GL 1.4/2.1).
+        #
+        # This only seems to work with wayland/EGL builds of
+        # wxPython. We assume that gtk3+wxpython>=4.1.1
+        # supports requesting a compatibility profile,
+        # but don't bother for gtk2+older wxpython
+        wxver  = fwidgets.wxVersion()
+        wxplat = fwidgets.wxPlatform()
+        if wxver is not None                               and \
+           fslversion.compareVersions(wxver, '4.1.1') >= 0 and \
+           wxplat in (fwidgets.WX_MAC_COCOA, fwidgets.WX_GTK3):
+            attrs = wxgl.GLContextAttrs()
+            attrs.CompatibilityProfile()
+            attrs.EndList()
+            kwargs = {'ctxAttrs' : attrs}
+        else:
+            kwargs = {}
+
         log.debug('Creating wx.GLContext')
 
         if other is not None:
-            self.__context = wxgl.GLContext(target, other=other)
+            self.__context = wxgl.GLContext(target, other=other, **kwargs)
 
         else:
-            self.__context = wxgl.GLContext(self.__canvas)
+            self.__context = wxgl.GLContext(self.__canvas, **kwargs)
 
             # We can't set the context target
             # until the dummy canvas is
@@ -794,7 +902,7 @@ class GLContext(object):
         self.__context = context
 
 
-class OffScreenCanvasTarget(object):
+class OffScreenCanvasTarget:
     """Base class for canvas objects which support off-screen rendering. """
 
     def __init__(self, width, height):
@@ -817,8 +925,7 @@ class OffScreenCanvasTarget(object):
 
     def _setGLContext(self):
         """Configures the GL context to render to this canvas. """
-        getGLContext().setTarget(self)
-        return True
+        return getGLContext().setTarget(self)
 
 
     def _draw(self, *a):
@@ -831,6 +938,20 @@ class OffScreenCanvasTarget(object):
         raise NotImplementedError()
 
 
+    def canvasToWorld(self, xpos, ypos):
+        """Convert X/Y pixel coordinates into a location in the display
+        coordinate system. Must be provided by subclasses.
+        """
+        raise NotImplementedError()
+
+
+    def worldToCanvas(self, pos):
+        """Convert a location in the display coordinate system into X/Y pixel
+        coordinates. Must be provided by subclasses.
+        """
+        raise NotImplementedError()
+
+
     def GetSize(self):
         """Returns a tuple containing the canvas width and height."""
         return self.__width, self.__height
@@ -908,22 +1029,7 @@ class OffScreenCanvasTarget(object):
         mplimg.imsave(filename, self.getBitmap())
 
 
-WXGLMetaClass = None
-"""Under Python3/wxPython-Phoenix, we must specify ``wx.siplib.wrappertype``
-as the meta-class.  This is not necessary under Python2/wxPython.
-"""
-
-
-if fslplatform.wxFlavour == fslplatform.WX_PHOENIX:
-
-    import wx.siplib as sip
-    WXGLMetaClass = sip.wrappertype
-
-else:
-    WXGLMetaClass = type
-
-
-class WXGLCanvasTarget(object):
+class WXGLCanvasTarget:
     """Base class for :class:`wx.glcanvas.GLCanvas` objects.
 
     It is assumed that subclasses of this base class are also subclasses of
@@ -935,9 +1041,83 @@ class WXGLCanvasTarget(object):
 
        _initGL
        _draw
+
+    And must also ensure that the :meth:`destroy` method is called when
+    the class is being destroyed.
     """
 
 
+    @staticmethod
+    def canToggleHighDPI():
+        """Return ``True`` if high-DPI scaling can be toggled, ``False``
+        otherwise.
+
+        Under GTK, high DPI support is not possible with wxPython < 4.0.7, as
+        ``wx.Window.GetContentScaleFactor`` always returns 1. Under GTK and
+        from wxPython 4.0.7 onwards, GL canvases are scaled automatically.
+
+        Under macOS and wxpython < 4.1.0, high DPI must be explicitly requested
+        for GL canvases via a Cocoa API call. This can be done via the
+        :meth:`EnableHighDPI` method.
+
+        Under macOS and with wxpython >= 4.1.0, GL canvases are scaled
+        automatically.
+        """
+
+        import wx
+
+        if platform.system() != 'Darwin':
+            return False
+
+        wxver = getattr(wx, '__version__', '1.0.0')
+        wxver = [int(v) for v in wxver.split('.')[:3]]
+
+        return wxver < [4, 1, 0]
+
+
+    @staticmethod
+    def displayAttribues():
+        """Used within ``__init__`` methods of ``WXGLCanvasTarget``
+        sub-classes.
+
+        Return a dict to be passed as keyword arguments to the
+        ``wx.glcanvas.GLCanvas.__init__`` method, defining display attributes.
+        The ``GLCanvas`` interface changed between wxWidgets 3.0.x and 3.1.x
+        (roughly corresponding to wxPython 4.0.x and 4.1.x) - this method
+        checks the wxPython version and returns a suitable set of arguments.
+        """
+
+        import wx
+        import wx.glcanvas as wxgl
+
+        # the format of wx.__version__ is not
+        # consistent (e.g. "4.0.7.post2", "4.1.0", etc)
+        try:
+            version = '.'.join(wx.__version__.split('.')[:3])
+        except Exception:
+            version = '4.0.0'
+
+        # Use new API for 4.1.0 and newer
+        if fslversion.compareVersions(version, '4.1.0') >= 0:
+            attrs = wxgl.GLAttributes()
+            attrs.MinRGBA(8, 8, 8, 8) \
+                 .DoubleBuffer()      \
+                 .Depth(24)           \
+                 .Stencil(4)          \
+                 .EndList()
+            kwargs = {'dispAttrs' : attrs}
+
+        else:
+            attrs = [wxgl.WX_GL_RGBA,
+                     wxgl.WX_GL_DOUBLEBUFFER,
+                     wxgl.WX_GL_STENCIL_SIZE, 4,
+                     wxgl.WX_GL_DEPTH_SIZE,   24,
+                     0,
+                     0]
+            kwargs = {'attribList' : attrs}
+        return kwargs
+
+
     def __init__(self):
         """Create a ``WXGLCanvasTarget``. """
 
@@ -951,7 +1131,7 @@ class WXGLCanvasTarget(object):
         # for each display. If we don't, then strange
         # refresh problems will occur.
         if platform.system() == 'Darwin' and \
-           'software' in fslplatform.glRenderer.lower():
+           'software' in GL_RENDERER.lower():
 
             log.debug('Creating separate GL context for '
                       'WXGLCanvasTarget {}'.format(id(self)))
@@ -963,12 +1143,7 @@ class WXGLCanvasTarget(object):
         self.__freezeSwapBuffers = False
         self.__context           = context
 
-        # Under macOS, high DPI must be explicitly
-        # requested for GL canvases. This can be
-        # done via the EnableHighDPI method. Under
-        # Linux, GL canvases are scaled the same as
-        # other windows.
-        if platform.system() == 'Darwin':
+        if WXGLCanvasTarget.canToggleHighDPI():
             self.__dpiscale = 1.0
         else:
             self.__dpiscale = self.GetContentScaleFactor()
@@ -977,6 +1152,22 @@ class WXGLCanvasTarget(object):
         self.Bind(wx.EVT_ERASE_BACKGROUND, self.__onEraseBackground)
 
 
+    def destroy(self):
+        """Must be called when this WXGLCanvasTarget is no longer in use.
+        Clears the GL rendering context target.
+        """
+        self.__context.setTarget(None)
+        self.__context = None
+
+
+    @property
+    def destroyed(self):
+        """Returns ``True`` if :meth:`destroy` has been called, ``False``
+        otherwise.
+        """
+        return self.__context is None
+
+
     def __onEraseBackground(self, ev):
         """Called on ``wx.EVT_ERASE_BACKGROUND`` events. Does nothing. """
         pass
@@ -1010,6 +1201,20 @@ class WXGLCanvasTarget(object):
         raise NotImplementedError()
 
 
+    def canvasToWorld(self, xpos, ypos):
+        """Convert X/Y pixel coordinates into a location in the display
+        coordinate system. Must be provided by subclasses.
+        """
+        raise NotImplementedError()
+
+
+    def worldToCanvas(self, pos):
+        """Convert a location in the display coordinate system into X/Y pixel
+        coordinates. Must be provided by subclasses.
+        """
+        raise NotImplementedError()
+
+
     def _draw(self, *a):
         """This method should implement the OpenGL drawing logic - it must be
         implemented by subclasses.
@@ -1044,6 +1249,9 @@ class WXGLCanvasTarget(object):
 
         def drawWrapper(*a, **kwa):
 
+            if self.destroyed:
+                return
+
             if not self.__freezeDraw:
                 subClassDraw(*a, **kwa)
 
@@ -1103,8 +1311,7 @@ class WXGLCanvasTarget(object):
         log.debug('Setting context target to {} ({})'.format(
             type(self).__name__, id(self)))
 
-        self.__context.setTarget(self)
-        return True
+        return self.__context.setTarget(self)
 
 
     def GetSize(self):
@@ -1191,9 +1398,10 @@ class WXGLCanvasTarget(object):
         """Attempts to enable/disable high-resolution rendering.
         """
 
-        # Not relevant under linux -
-        # see note in __init__
-        if platform.system() != 'Darwin':
+        # We don't necessarily need to
+        # enable high-DPI support - see
+        # __init__.
+        if not WXGLCanvasTarget.canToggleHighDPI():
             return
 
         if not self._setGLContext():
