@@ -11,21 +11,18 @@ that plots the histogram of data from :class:`.Image` overlays.
 
 import logging
 
-import wx
-
 import numpy as np
 
-import fsl.data.image                         as fslimage
-import fsl.data.mesh                          as fslmesh
-import fsleyes_props                          as props
+import fsl.data.image                    as fslimage
+import fsl.data.mesh                     as fslmesh
+import fsleyes_props                     as props
+
+import fsleyes.actions                   as actions
+import fsleyes.overlay                   as fsloverlay
+import fsleyes.views.plotpanel           as plotpanel
+import fsleyes.profiles.histogramprofile as histogramprofile
+import fsleyes.plotting.histogramseries  as histogramseries
 
-import fsleyes.actions                        as actions
-import fsleyes.actions.addroihistogram        as roihistogram
-import fsleyes.overlay                        as fsloverlay
-import fsleyes.plotting.histogramseries       as histogramseries
-import fsleyes.controls.histogramcontrolpanel as histogramcontrolpanel
-import fsleyes.controls.histogramtoolbar      as histogramtoolbar
-from . import                                    plotpanel
 
 
 log = logging.getLogger(__name__)
@@ -45,30 +42,14 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
     each of which encapsulate histogram data from an :class:`.Image` overlay.
 
 
-    A couple of control panels may be shown on a ``HistogramPanel``:
+    A couple of control panels may be shown on a ``HistogramPanel``, via
+    :meth:`.ViewPanel.togglePanel`:
 
     .. autosummary::
        :nosignatures:
 
        ~fsleyes.controls.plotlistpanel.PlotListPanel
        ~fsleyes.controls.histogramcontrolpanel.HistogramControlPanel
-
-
-    The following :mod:`actions` are provided, in addition to those already
-    provided by the :class:`.PlotPanel`:
-
-    .. autosummary::
-       :nosignatures:
-
-       toggleHistogramToolBar
-       toggleHistogramControl
-
-    Some tools are also available, to do various things:
-
-    .. autosummary::
-       :nosignatures:
-
-       addROIHistogram
     """
 
 
@@ -95,6 +76,27 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
     """
 
 
+    @staticmethod
+    def defaultLayout():
+        """Returns a list of control panel types to be added for the default
+        histogram panel layout.
+        """
+        return ['HistogramToolBar',
+                'OverlayListPanel',
+                'PlotListPanel']
+
+
+    @staticmethod
+    def controlOrder():
+        """Returns a list of control panel names, specifying the order in
+        which they should appear in the  FSLeyes ortho panel settings menu.
+        """
+        return ['OverlayListPanel',
+                'PlotListPanel',
+                'HistogramToolBar',
+                'HistogramControlPanel']
+
+
     def __init__(self, parent, overlayList, displayCtx, frame):
         """Create a ``HistogramPanel``.
 
@@ -118,14 +120,7 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
                                 self.name,
                                 self.__selectedOverlayChanged)
 
-        self.__roiHistAction = roihistogram.AddROIHistogramAction(
-            overlayList,
-            displayCtx,
-            self)
-
-        self.addROIHistogram.bindProps('enabled', self.__roiHistAction)
-
-        self.initProfile()
+        self.initProfile(histogramprofile.HistogramProfile)
         self.__selectedOverlayChanged()
 
 
@@ -134,10 +129,7 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
         :meth:`.PlotPanel.destroy`.
         """
 
-        self.__roiHistAction.destroy()
-
-        self.__currentHs     = None
-        self.__roiHistAction = None
+        self.__currentHs = None
 
         self            .removeListener('histType',        self.name)
         self            .removeListener('plotType',        self.name)
@@ -147,25 +139,6 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
         plotpanel.OverlayPlotPanel.destroy(self)
 
 
-    @actions.toggleControlAction(histogramcontrolpanel.HistogramControlPanel)
-    def toggleHistogramControl(self, floatPane=False):
-        """Shows/hides a :class:`.HistogramControlPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(histogramcontrolpanel.HistogramControlPanel,
-                         self,
-                         location=wx.RIGHT,
-                         floatPane=floatPane)
-
-
-    @actions.toggleControlAction(histogramtoolbar.HistogramToolBar)
-    def toggleHistogramToolBar(self):
-        """Shows/hides a :class:`.HistogramToolBar`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(histogramtoolbar.HistogramToolBar, histPanel=self)
-
-
     @actions.toggleAction
     def toggleHistogramOverlay(self):
         """Toggles the value of the :attr:`.HistogramSeries.showOverlay`
@@ -176,37 +149,17 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
         pass
 
 
-    @actions.action
-    def addROIHistogram(self):
-        """Runs an :class:`.AddROIHistogramAction`. """
-
-        self.__roiHistAction()
-
-
     def getActions(self):
         """Overrides :meth:`.ActionProvider.getActions`. Returns all of the
         :mod:`.actions` that are defined on this ``HistogramPanel``.
         """
-        actions = [self.screenshot,
+        actionz = [self.screenshot,
                    self.importDataSeries,
                    self.exportDataSeries,
-                   None,
-                   self.toggleOverlayList,
-                   self.togglePlotList,
-                   self.toggleHistogramToolBar,
-                   self.toggleHistogramControl,
                    self.toggleHistogramOverlay]
 
-        names = [a.__name__ if a is not None else None for a in actions]
-
-        return list(zip(names, actions))
-
-
-    def getTools(self):
-        """Returns a list of tools to be added to the ``FSLeyesFrame`` for
-        ``HistogramPanel`` views.
-        """
-        return [self.addROIHistogram]
+        names = [a.actionName if a is not None else None for a in actionz]
+        return list(zip(names, actionz))
 
 
     def draw(self, *a):
@@ -218,20 +171,21 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
         if not self or self.destroyed:
             return
 
-        hss = self.getDataSeriesToPlot()
+        canvas = self.canvas
+        hss    = self.getDataSeriesToPlot()
 
         for hs in hss:
             with props.suppress(hs, 'label'):
                 hs.label = self.displayCtx.getDisplay(hs.overlay).name
 
-        if self.smooth or self.plotType == 'centre':
-            self.drawDataSeries(hss)
+        if canvas.smooth or self.plotType == 'centre':
+            canvas.drawDataSeries(hss)
 
         # use a step plot when plotting bin edges
         else:
-            self.drawDataSeries(hss, drawstyle='steps-pre')
+            canvas.drawDataSeries(hss, drawstyle='steps-pre')
 
-        self.drawArtists()
+        canvas.drawArtists()
 
 
     def createDataSeries(self, overlay):
@@ -252,7 +206,7 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
         else:
             return None, None, None
 
-        hs = hsType(overlay, self.overlayList, self.displayCtx, self)
+        hs = hsType(overlay, self.overlayList, self.displayCtx, self.canvas)
         hs.colour      = self.getOverlayPlotColour(overlay)
         hs.lineStyle   = self.getOverlayPlotStyle(overlay)
         hs.lineWidth   = 2
@@ -278,7 +232,7 @@ class HistogramPanel(plotpanel.OverlayPlotPanel):
 
         # If smoothing is enabled, we just
         # need to provide the data as-is
-        if self.smooth:
+        if self.canvas.smooth:
             xdata = np.array(xdata[:-1], dtype=np.float32)
             ydata = np.array(ydata,      dtype=np.float32)
 
